@@ -4,7 +4,7 @@ try:
 except ImportError:
     from ordereddict import OrderedDict
 from decimal import Decimal
-from string import strip
+import six
 from wtforms import (
     BooleanField,
     FloatField,
@@ -58,6 +58,7 @@ from .utils import (
     is_integer_column,
     is_scalar,
     null_or_unicode,
+    strip_string
 )
 
 
@@ -342,7 +343,7 @@ class FormGenerator(object):
             ) or
             should_trim is True
         ):
-            filters.append(strip)
+            filters.append(strip_string)
         return filters
 
     def date_format(self, column):
@@ -451,7 +452,10 @@ class FormGenerator(object):
 
         :param column: SQLAlchemy Column object
         """
-        if column.nullable and column.type.python_type in (unicode, str):
+        if (
+            column.nullable and
+            issubclass(column.type.python_type, six.string_types)
+        ):
             return null_or_unicode
         try:
             return column.type.python_type
